# Setup

Make sure that you have the following installed:
- Python 3
- WSL's Ubuntu (Or some other Linux distro)
- You can run virtual enviroments

Go to the location where you want to clone the repo

Clone repo: `git clone https://github.com/GaboxFH/cis4930-carfinder.git`

Go to new folder `cd cis4930-carfinder/`

Start a venv `python3 -m venv venv`

Activate venv `. venv/bin/activate`

Install packages in requirements.txt `pip install -r requirements.txt`

Run python server: `python3 manage.py runserver`

Go to `http://127.0.0.1:8000/` in a browser.

Page should render, let me know in Teams if you run into any issues.
